<html>
<head>
<title>organizationalPerson: Other Tab</title>
<style type="text/css">
<!--
h1 {  font-family: Arial, Helvetica, sans-serif; color: #006666}
body {  font-family: Arial, Helvetica, sans-serif}
-->
</style>
</head>
<body bgcolor="#ffffff">
<form name="Person">
  <table>
    <tr> 
      <td align="center" valign="top" colspan="2">
        <p><img src="../images/ca_logo.gif" width="200" height="45"/></p>
        <table border="0" cellpadding="0" cellspacing="0" width="300">
            <tr valign="top"> 
            <td><a href="Main.html"><img name="main" src="../images/main.gif" width="100" height="20" border="0"/></a></td>
            <td><a href="address.html"><img name="address" src="../images/address.gif" width="100" height="20" border="0"/></a></td>
            <td><img name="other" src="../images/other2.gif" width="100" height="20" border="0"/></td>
            </tr>
          </table>
          
        <h1>organizationalPerson</h1>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">See Also:</td>
      <td width="230"> 
        <input type="text" name="seeAlso" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">Delivery Office 
        Name:</td>
      <td width="230"> 
        <input type="text" name="physicalDeliveryOfficeName" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">ISDN Number:</td>
      <td width="230"> 
        <input type="text" name="internationaliSDNNumber" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">Teletex Id:</td>
      <td width="230"> 
        <input type="text" name="teletexTerminalIdentifier" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">Telex Number:</td>
      <td width="230"> 
        <input type="text" name="telexNumber" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">Preferred Delivery:</td>
      <td width="230"> 
        <input type="text" name="preferredDeliveryMethod" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">Destination Indicator:</td>
      <td width="230"> 
        <input type="text" name="destinationIndicator" value=""/>
      </td>
    </tr>
    <tr> 
      <td align="right" valign="top"  width="200" class="title">X.121 Address:</td>
      <td width="230"> 
        <input type="text" name="x121Address" value=""/>
      </td>
    </tr>
    <tr> 
      <td width="200"></td>
      <td width="230"> 
        <div align="left"> 
          <input type="submit" name="Submit" value="Submit"/>
          &#160; 
          <input type="reset"/>
        </div>
      </td>
    </tr>
  </table>
</form>
</body>
</html>

