<html>
<head>
<title>Schema List: displays the schema</title>
</head>
<body bgcolor="#F0F8FF">

<center><img src="JXBanner.gif" width="454" height="69" border="1"/></center>

<h2><font face="arial">Schema List: displays the schema...</font></h2>

<dxtemplate:get-all-attributes style="list"/>
</body>
</html>
