<html>
<head>
<title>First Template</title>
</head>
<body>

<table width="100%" border="0" cellpadding="0" cellspacing="0">
  <tr bgcolor="#FFFFFF"> 
    <td><img src="ca_logo.gif"/></td>
  </tr>
  <tr background="topbar_center.gif"> 
    <td>&#160;</td>
  </tr>
  <tr> 
    <td><br/>
      <h2>Country Attribute Data...</h2>
		<dxtemplate:get-all-attributes style="list"/>
      <p/>
    </td>
  </tr>
</table>
</body>
</html>
